@@ -16,13 +16,18 @@ Params = TypedDict('Params', {
     'version': int,
     'cmds': List[Command],
     'format': str,
-    'timestamps': bool
+    'timestamps': bool,
+	'auto_complete': bool,
+	'expand_aliases': bool,
+	'include_error_detail': bool,
+	'streaming': bool # not support until 4.24
 }, total=False)
 
 Request = TypedDict('Request', {
     'id': str,
     'jsonrpc': str,
     'method': str,
+    'streaming': bool, # eAPI hack
     'params': Params
 }, total=False)
 
@@ -33,9 +38,9 @@ Certificate = Optional[Union[str, Tuple[str, str], Tuple[str, str, str]]]
 
 Timeout = Union[None, float, Tuple[float, float, float, float]]
 
-RequestsOptions = TypedDict('RequestsOptions', {
-    'auth': Auth,
-    'timeout': Timeout,
-    'cert': Certificate,
-    'verify': bool
-}, total=False)
+# RequestsOptions = TypedDict('RequestsOptions', {
+#     'auth': Auth,
+#     'timeout': Timeout,
+#     'cert': Certificate,
+#     'verify': bool
+# }, total=False)
